searchData={"items":[{"type":"module","title":"Alchemind.OpenAI","doc":"OpenAI provider implementation for the Alchemind LLM interface.\n\nThis module implements the Alchemind behaviour for interacting with OpenAI's API.","ref":"Alchemind.OpenAI.html"},{"type":"function","title":"Alchemind.OpenAI.complete/4","doc":"Completes a conversation using OpenAI's API with optional streaming.","ref":"Alchemind.OpenAI.html#complete/4"},{"type":"function","title":"Parameters - Alchemind.OpenAI.complete/4","doc":"- `client`: OpenAI client created with new/1\n- `messages`: List of messages in the conversation\n- `callback_or_opts`: Callback function for streaming (not supported) or options\n- `opts`: Additional options for the completion request (when callback is provided)","ref":"Alchemind.OpenAI.html#complete/4-parameters"},{"type":"function","title":"Options - Alchemind.OpenAI.complete/4","doc":"- `:model` - OpenAI model to use (required unless specified in client)\n- `:temperature` - Controls randomness (0.0 to 2.0)\n- `:max_tokens` - Maximum number of tokens to generate","ref":"Alchemind.OpenAI.html#complete/4-options"},{"type":"function","title":"Examples - Alchemind.OpenAI.complete/4","doc":"Using model in options:\n\n    iex> {:ok, client} = Alchemind.OpenAI.new(api_key: \"sk-...\")\n    iex> messages = [\n    ...>   %{role: :system, content: \"You are a helpful assistant.\"},\n    ...>   %{role: :user, content: \"Hello, world!\"}\n    ...> ]\n    iex> Alchemind.OpenAI.complete(client, messages, model: \"gpt-4o\", temperature: 0.7)\n\nUsing default model from client:\n\n    iex> {:ok, client} = Alchemind.OpenAI.new(api_key: \"sk-...\", model: \"gpt-4o\")\n    iex> messages = [\n    ...>   %{role: :system, content: \"You are a helpful assistant.\"},\n    ...>   %{role: :user, content: \"Hello, world!\"}\n    ...> ]\n    iex> Alchemind.OpenAI.complete(client, messages, temperature: 0.7)\n\nNote: Streaming is not supported in the direct OpenAI implementation.\nUse OpenAILangChain for streaming support.","ref":"Alchemind.OpenAI.html#complete/4-examples"},{"type":"function","title":"Alchemind.OpenAI.complete_chat/3","doc":"","ref":"Alchemind.OpenAI.html#complete_chat/3"},{"type":"function","title":"Alchemind.OpenAI.create_client/2","doc":"","ref":"Alchemind.OpenAI.html#create_client/2"},{"type":"function","title":"Alchemind.OpenAI.new/1","doc":"Creates a new OpenAI client.","ref":"Alchemind.OpenAI.html#new/1"},{"type":"function","title":"Options - Alchemind.OpenAI.new/1","doc":"- `:api_key` - OpenAI API key (required)\n- `:base_url` - API base URL (default: https://api.openai.com/v1)\n- `:model` - Default model to use (optional, can be overridden in complete calls)","ref":"Alchemind.OpenAI.html#new/1-options"},{"type":"function","title":"Examples - Alchemind.OpenAI.new/1","doc":"iex> Alchemind.OpenAI.new(api_key: \"sk-...\")\n    {:ok,  }\n\n    iex> Alchemind.OpenAI.new(api_key: \"sk-...\", model: \"gpt-4o\")\n    {:ok,  }","ref":"Alchemind.OpenAI.html#new/1-examples"},{"type":"function","title":"Returns - Alchemind.OpenAI.new/1","doc":"- `{:ok, client}` - OpenAI client\n- `{:error, reason}` - Error with reason","ref":"Alchemind.OpenAI.html#new/1-returns"},{"type":"function","title":"Alchemind.OpenAI.process_completion_chunk/5","doc":"","ref":"Alchemind.OpenAI.html#process_completion_chunk/5"},{"type":"function","title":"Alchemind.OpenAI.speech/3","doc":"Converts text to speech using OpenAI's API.","ref":"Alchemind.OpenAI.html#speech/3"},{"type":"function","title":"Parameters - Alchemind.OpenAI.speech/3","doc":"- `client`: OpenAI client created with new/1\n- `input`: Text to convert to speech\n- `opts`: Options for the speech request","ref":"Alchemind.OpenAI.html#speech/3-parameters"},{"type":"function","title":"Options - Alchemind.OpenAI.speech/3","doc":"- `:model` - OpenAI text-to-speech model to use (default: \"gpt-4o-mini-tts\")\n- `:voice` - Voice to use (default: \"alloy\")\n- `:response_format` - Format of the audio (default: \"mp3\")\n- `:speed` - Speed of the generated audio (optional)","ref":"Alchemind.OpenAI.html#speech/3-options"},{"type":"function","title":"Examples - Alchemind.OpenAI.speech/3","doc":"iex> {:ok, client} = Alchemind.OpenAI.new(api_key: \"sk-...\")\n    iex> Alchemind.OpenAI.tts(client, \"Hello, world!\", voice: \"echo\")\n    {:ok, < >}","ref":"Alchemind.OpenAI.html#speech/3-examples"},{"type":"function","title":"Returns - Alchemind.OpenAI.speech/3","doc":"- `{:ok, audio_binary}` - Successful speech generation with audio binary\n- `{:error, reason}` - Error with reason","ref":"Alchemind.OpenAI.html#speech/3-returns"},{"type":"function","title":"Alchemind.OpenAI.text_to_speech/3","doc":"","ref":"Alchemind.OpenAI.html#text_to_speech/3"},{"type":"function","title":"Alchemind.OpenAI.transcribe/3","doc":"Transcribes audio to text using OpenAI's API.","ref":"Alchemind.OpenAI.html#transcribe/3"},{"type":"function","title":"Parameters - Alchemind.OpenAI.transcribe/3","doc":"- `client`: OpenAI client created with new/1\n- `audio_binary`: Binary audio data\n- `opts`: Options for the transcription request","ref":"Alchemind.OpenAI.html#transcribe/3-parameters"},{"type":"function","title":"Options - Alchemind.OpenAI.transcribe/3","doc":"- `:model` - OpenAI transcription model to use (default: \"whisper-1\")\n- `:language` - Language of the audio (default: nil, auto-detect)\n- `:prompt` - Optional text to guide the model's transcription\n- `:response_format` - Format of the transcript (default: \"json\")\n- `:temperature` - Controls randomness (0.0 to 1.0, default: 0)","ref":"Alchemind.OpenAI.html#transcribe/3-options"},{"type":"function","title":"Examples - Alchemind.OpenAI.transcribe/3","doc":"iex> {:ok, client} = Alchemind.OpenAI.new(api_key: \"sk-...\")\n    iex> audio_binary = File.read!(\"audio.mp3\")\n    iex> Alchemind.OpenAI.transcribe(client, audio_binary, language: \"en\")\n    {:ok, \"This is a transcription of the audio.\"}","ref":"Alchemind.OpenAI.html#transcribe/3-examples"},{"type":"function","title":"Returns - Alchemind.OpenAI.transcribe/3","doc":"- `{:ok, text}` - Successful transcription with text\n- `{:error, reason}` - Error with reason","ref":"Alchemind.OpenAI.html#transcribe/3-returns"},{"type":"function","title":"Alchemind.OpenAI.transcribe_audio/3","doc":"","ref":"Alchemind.OpenAI.html#transcribe_audio/3"},{"type":"module","title":"Alchemind.OpenAI.Message","doc":"Defines the Message struct for NIF compatibility.","ref":"Alchemind.OpenAI.Message.html"},{"type":"extras","title":"Alchemind OpenAI","doc":"# Alchemind OpenAI\n\nOpenAI provider implementation for the Alchemind project.\n\n> [!WARNING]  \n> This project is currently in early development and should not be used in production environments.","ref":"readme.html"},{"type":"extras","title":"Overview - Alchemind OpenAI","doc":"This package implements the Alchemind interfaces for OpenAI's API, allowing you to interact with OpenAI models using the consistent Alchemind API. It provides access to OpenAI's chat completion, speech-to-text, and text-to-speech capabilities.\n\nUnder the hood, this package uses the rust crate [async-openai](https://github.com/64bit/async-openai).","ref":"readme.html#overview"},{"type":"extras","title":"Features - Alchemind OpenAI","doc":"| Feature | Support |\n|---------|:-------:|\n| Chat Completions |  |\n| &nbsp;&nbsp;&nbsp;&nbsp;Create chat completion | ✅ |\n| &nbsp;&nbsp;&nbsp;&nbsp;Streaming | ✅ |\n| Audio |  |\n| &nbsp;&nbsp;&nbsp;&nbsp;Create Speech | ✅ |\n| &nbsp;&nbsp;&nbsp;&nbsp;Create Transcription | ✅ |","ref":"readme.html#features"},{"type":"extras","title":"Installation - Alchemind OpenAI","doc":"The package can be installed by adding `alchemind_openai` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:alchemind, \"~> 0.1.0-rc1\"},\n    {:alchemind_openai, \"~> 0.1.0-rc.1\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Development - Alchemind OpenAI","doc":"You can run tests specifically for this package with:\n\n```bash\ncd apps/alchemind_openai\nmix test\n```","ref":"readme.html#development"},{"type":"extras","title":"License - Alchemind OpenAI","doc":"See the [LICENSE](LICENSE) file for details.","ref":"readme.html#license"},{"type":"extras","title":"Release Process - Alchemind OpenAI","doc":"This package utilizes precompiled Rust NIFs managed by [`rustler_precompiled`](https://hexdocs.pm/rustler_precompiled/). The release process involves GitHub Actions for building the NIFs and a manual step for preparing the Hex package.\n\n**Steps:**\n\n1. Push changes to [mirror repository](https://github.com/bradleygolden/alchemind-openai): `git subtree push --prefix=apps/alchemind_openai openai-mirror  `\n2. Wait for NIFs to be built\n3. Tag the release in the mirror repository\n4. Wait for NIFs to be built\n5. Run `mix rustler_precompiled.download Alchemind.OpenAI --all` to generate a `checksum-*.exs`\n6. Release package to Hex.pm via `mix hex.publish`","ref":"readme.html#release-process"},{"type":"extras","title":"LICENSE","doc":"MIT License\n\nCopyright (c) 2025 Bradley Golden\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}